<?php if (!defined('APPLICATION')) exit();
/*Copyright 2014 Zachary Doll */
$PluginInfo['DateSeparators'] = array(
	'Name' => 'Date Separators',
	'Description' => 'Adds date separators to the discussion list.',
	'Version' => '0.1',
	'RequiredApplications' => array('Vanilla' => '2.1.6'),
	'RequiredTheme' => FALSE,
	'RequiredPlugins' => FALSE,
	'MobileFriendly' => TRUE,
	'HasLocale' => FALSE,
	'RegisterPermissions' => FALSE,
    'Author' => 'Zachary Doll and VanillaSkins.com',
	'AuthorEmail' => 'sales@vanillaskins.com',
	'AuthorUrl' => 'http://www.vanillaskins.com',
	'License' => 'GPLv3'
);

class DateSeparators extends Gdn_Plugin {
  private $Tomorrow;
  private $Today;
  private $Yesterday;
  private $Announcements = 0;
  
  public function __construct() {
    $this->Tomorrow = new DateTime('tomorrow');
    $this->Today = new DateTime('today');
    $this->Yesterday = new DateTime('yesterday');
    parent::__construct();
  }

  /**
   * Find the count of announcements on the discussions page
   * @param type $Sender
   */
  public function DiscussionsController_Render_Before($Sender) {
    $this->SetAnnouncementCount($Sender->Announcements);
  }
  
  /**
   * Display the date of the following discussions on the discussions list
   * @staticvar int $Index
   * @param type $Sender
   */
  public function DiscussionsController_BetweenDiscussion_Handler($Sender) {
    $this->RenderSeparator($Sender->Discussions);
    $this->AddResources($Sender);
  }

  /**
   * Find the count of announcements on the categories page
   * @param type $Sender
   */
  public function CategoriesController_Render_Before($Sender) {
    $this->SetAnnouncementCount($Sender->AnnounceData);
    $this->AddResources($Sender);
  }
  
  /**
   * Display date seperators between discussions on the categories view
   * @param type $Sender
   */
  public function CategoriesController_BetweenDiscussion_Handler($Sender) {
    $this->RenderSeparator($Sender->DiscussionData);
  }
  
  /**
   * Render a date label if needed.
   * @staticvar int $Index
   * @param type $DataSet
   */
  private function RenderSeparator($DataSet) {
    static $Index = 0;
    
    // Skip any announcements on the page
    if($Index >= $this->Announcements) {
      $PrevDiscussion = $DataSet->Row($Index - $this->Announcements - 1) ?: (object)array('LastDate' => $this->Tomorrow->format("Y-m-d H:i:s"));
      $NextDiscussion = $DataSet->Row($Index - $this->Announcements);

      $PrevDate = new DateTime(substr($PrevDiscussion->LastDate, 0, 10));
      $NextDate = new DateTime(substr($NextDiscussion->LastDate, 0, 10));

      $Diff = date_diff($NextDate, $PrevDate);
      if($Diff->d != 0) {
        echo Wrap($this->GetDateString($NextDate), 'li', array('class' => 'Item DateSeperator'));
      }
    }
    
    $Index++;
  }
  
  private function GetDateString($Date) {
    $String = '';
    if($Date == $this->Yesterday) {
      $String = T('Yesterday');
    }
    else if($Date == $this->Today) {
      $String = T('Today');
    }
    else {
      $String = strftime(C('DateSeparators.Format'), $Date->getTimestamp());
    }
    return $String;
  }
  
  private function SetAnnouncementCount($DataSet) {
    if($DataSet) {
      $this->Announcements = count($DataSet->Result()) - 1 ?: 0;
    }
  }
  
  private function AddResources($Sender) {
    //$Sender->AddJsFile($this->GetResource('js/dateseparators.js', FALSE, FALSE));
		$Sender->AddCssFile($this->GetResource('design/dateseparators.css', FALSE, FALSE));
  }
  
  public function Setup() {
    if(C('DateSeparators.Format') == FALSE) {
      SaveToConfig('DateSeparators.Format', '%B %e');
    }
  }
}
